// This is just an example,
// so you can safely delete all default props below

export default {
  failed: 'Action failed',
  success: 'Action was successful',
  title: 'GreaterWMS Open Source Warehouse Management System',
  description: 'GreaterWMS Open Source Warehouse Management System',
  keywords: 'greaterwms, 聚商汇wms,wms-system,open source wms system,开源wms,开源仓库管理软件,warehouse management system, free wms',
  gohome: 'Go Home',
  cancel: 'Cancel',
  submit: 'Submit',
  login: 'Login',
  register: 'Register',
  passworderror: 'Password Is Not The Same',
  logout: 'Logout',
  logoutnotice: 'Welcome Back Again',
  username: 'User Name',
  password: 'Enter Password',
  password1: 'Enter Password',
  password2: 'Enter Password Again',
  usererror: 'User Name Or Password Cannot Be Empty',
  nodata: 'No more data',
  total: 'Total: ',
  page: 'page',
  per_page: 'Per page lines',
  refresh: 'Refresh Data',
  new: 'New one user',
  email: 'E-Mail',
  date_joined: 'Date Joined',
  last_login: 'Last Login',
  created_time: 'Created Time',
  updated_time: 'Updated Time',
  action: 'Action',
  menuTab: {
    home: 'Home',
  },
  menuLink: {
    home: 'Home',
    user: 'User List',
  },
  400: 'Bad request (400)',
  401: 'Authorization not obtained (401)',
  403: 'Access denied (403)',
  404: 'Resource does not exist (404)',
  405: 'The function is disabled (405)',
  408: 'Request timed out (408)',
  409: 'Data conflict (409)',
  410: 'Data has been deleted (410)',
  500: 'Server error (500)',
  501: 'Service not implemented (501)',
  502: 'Network error (502)',
  503: 'Service unavailable (503)',
  504: 'Network timeout (504)',
  505: 'HTTP version is not supported (505)'
}
