// This is just an example,
// so you can safely delete all default props below

export default {
  failed: '失败',
  success: '成功',
  title: 'Bomiot',
  description: 'GreaterWMS开源仓库管理系统',
  keywords: 'greaterwms, 聚商汇wms,wms-system,open source wms system,开源wms,开源仓库管理软件,warehouse management system, free wms',
  gohome: '回到首页',
  cancel: '取消',
  submit: '提交',
  login: '登入',
  register: '注册',
  passworderror: '两次输入的密码不一样',
  logout: '退出',
  logoutnotice: '欢迎再来',
  username: '用户名',
  password: '输入密码',
  password1: '输入密码',
  password2: '再次输入密码',
  usererror: '用户名或密码不能为空',
  nodata: '没有请求到任何数据',
  total: '总共：',
  page: '页',
  per_page: '每页多少行',
  refresh: '刷新数据',
  new: '新增用户',
  email: 'E-Mail',
  date_joined: '创建时间',
  last_login: '最后登入时间',
  created_time: '创建时间',
  updated_time: '更新时间',
  action: '操作',
  menuTab: {
    home: '首页',
  },
  menuLink: {
    home: '首页',
    user: '用户列表',
  },
  400: '错误请求(400)',
  401: '未取得授权(401)',
  403: '拒绝访问(403)',
  404: '资源不存在(404)',
  405: '该功能被禁用(405)',
  408: '请求超时(408)',
  409: '数据冲突(409)',
  410: '数据已删除(410)',
  500: '服务器错误(500)',
  501: '服务未实现(501)',
  502: '网络错误(502)',
  503: '服务不可用(503)',
  504: '网络超时(504)',
  505: 'HTTP版本不受支持(505)'
}
